% example
clear
load abalone
load abaloneindex;

% initialize the free parameters
trainnum            = 3000;
param.kernel        = 'rbf';
param.kernelparam   = 0.5; 
param.epsilon       = 0.1;
param.delta         = 0.11; 
param.lamda         = (param.delta - param.epsilon)/10;
type                = 'normal';

for i = 1:10
    % normalize the data
    index1          = abaloneindex(i,1:trainnum);
    index2          = abaloneindex(i,trainnum+1:end);
    [samples,A1,B1] = scaletrain(abalonesamples(index1,:));
    [labels,A2,B2]  = scaletrain(abalonelabels(index1,:));
    mul             = 1/A2;
    testsamples     = scaletest(abalonesamples(index2,:),A1,B1);
    testlabels      = scaletest(abalonelabels(index2,:),A2,B2);

    % train support vector regression with recursive finite Newton algorithm
    [alpha,b,sv]    = ihlf_svr_rfntrain(samples,labels,param,type);
    trainresult     = ihlf_svr_rfntest(samples,samples,alpha,b,sv,param);
    testresult      = ihlf_svr_rfntest(testsamples,samples,alpha,b,sv,param);
    lensv(i,1)      = length(sv);
    
    % print the training and test error
    trainerror(i,1) = mean((mul*(trainresult - labels)).^2);
    testerror(i,1)  = mean((mul*(testresult - testlabels)).^2);
    fprintf('\n');
    fprintf('Test     error = %f\n',mean(testerror));
    fprintf('Train    error = %f\n',mean(trainerror));
    fprintf('Support vector = %f\n',mean(lensv));
    fprintf('\n');
end