function result = ihlf_svr_rfntest(testsamples,samples,alpha,b,sv,param)
% evaluate the estimated output of the input
%
% input parameters
% samples: n*d matrix vector
% targets: n vector
% alpha:  weight vector
% b:      threshold 
% sv:     support vector
% param:   aus parameters
%   param.kernel:       kernel type
%   param.kernelparam:  kernel parameter
%   param.lamda:        regular constant
%   param.epsilon:      insensitive parameter
%   param.delta:        Huber parameter
%
% output parameters
% result the estimated outpur of the input
%
% written by Liefeng Bo on 12/12/2005
% version 1.0

nsv = length(sv);
n = size(testsamples,1);
memsize = 5000000; % size of memory can be set according to own computer
batchsize = floor(memsize/nsv);
if batchsize > n
    ktestsamples = evalkernel(testsamples,samples(sv,:),param.kernel,param.kernelparam);
    result = ktestsamples*alpha + b;
else
    num = floor(n/batchsize);
    result = [];
    for i = 1:num
        ktestsamples = evalkernel(testsamples((i-1)*batchsize+1:i*batchsize,:),samples(sv,:),param.kernel,param.kernelparam);
        result = [result; ktestsamples*alpha];
    end
    if batchsize*num < n
        ktestsamples = evalkernel(testsamples(num*batchsize+1:end,:),samples(sv,:),param.kernel,param.kernelparam);
        result = [result; ktestsamples*alpha];
    end
    result = result + b;
end