function [alpha,b,sv] = ihlf_svr_rfntrain(samples,targets,param,type)
% recursive finite Newton algorithm for support vector regression
% interface function of ihlf_svr_rfntrain_fast,ihlf_svr_rfntrain_normal and ihlf_svr_rfntrain_save
%
% input parameters
% samples: n*d matrix vector
% targets: n vector
% param:   aus parameters
%   param.kernel:       kernel type
%   param.kernelparam:  kernel parameter
%   param.lamda:        regular constant
%   param.epsilon:      insensitive parameter
%   param.delta:        Huber parameter
%   type:               'normal','fast','save'; the cost of 'normal' is
%   n*nsv,that of 'fast' is n*n and that of 'save' is nsv*nsv; 
%
% output parameters
% alpha:  weight vector
% b:      threshold 
% sv:     support vector
%
% written by Liefeng Bo on 12/12/2005
% version 1.0

switch type
    case 'normal'
        [alpha,b,sv] = ihlf_svr_rfntrain_normal(samples,targets,param);
    case 'fast'
        [alpha,b,sv] = ihlf_svr_rfntrain_fast(samples,targets,param);
    case 'save'
        [alpha,b,sv] = ihlf_svr_rfntrain_save(samples,targets,param);
    otherwise
      error('Unknown type');  
end